[grisbi-cvs] [SCM] grisbi branch, master, updated. upstream_version_0_7_96-4-g7a1660b

Pierre Biava nobody at users.sourceforge.net
Wed Dec 15 23:15:58 CET 2010


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "grisbi".

The branch, master has been updated
       via  7a1660b615c71be4bc4a6cf0a0e97504b0b1c338 (commit)
      from  b665b10d5e5ad51845dcee897862885cc4f62020 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 7a1660b615c71be4bc4a6cf0a0e97504b0b1c338
Author: pbiava <pierre.biava at nerim.net>
Date:   Wed Dec 15 23:14:43 2010 +0100

    Added ability to change the alignment of columns in the list of operations

-----------------------------------------------------------------------

Changes:
diff --git a/src/etats_affiche.c b/src/etats_affiche.c
index cdd69a7..6154bfa 100644
--- a/src/etats_affiche.c
+++ b/src/etats_affiche.c
@@ -117,7 +117,7 @@ gint etat_affiche_affiche_titre ( gint ligne )
     titre = etats_titre (gsb_gui_navigation_get_current_report ()) ;
 
     etat_affiche_attach_label ( titre, TEXT_BOLD | TEXT_HUGE, 0, nb_colonnes,
-				ligne, ligne + 1, LEFT, 0 );
+				ligne, ligne + 1, ALIGN_LEFT, 0 );
 
     return 1;
 }
@@ -164,7 +164,7 @@ gint etat_affiche_affiche_total_categories ( gint ligne )
 	     ||
 	     gsb_data_report_get_show_report_transactions (current_report_number) )
 	{
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes -1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes -1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -199,16 +199,16 @@ gint etat_affiche_affiche_total_categories ( gint ligne )
 		    text = g_strdup(COLON(_("Category total")));
 	    }
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1,
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
             g_free ( text );
 
 	    text = gsb_real_get_string_with_currency (montant_categ_etat, devise_categ_etat, TRUE );
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes,
-					ligne, ligne + 1, RIGHT, 0 );
+					ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes -1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes -1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 
 	    ligne++;
 	}
@@ -234,7 +234,7 @@ gint etat_affiche_affiche_total_categories ( gint ligne )
 							   devise_categ_etat, TRUE );
 
 	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes,
-					ligne, ligne + 1, RIGHT, 0 );
+					ligne, ligne + 1, ALIGN_RIGHT, 0 );
             g_free ( text );
 
 	    ligne++;
@@ -284,7 +284,7 @@ gint etat_affiche_affiche_total_sous_categ ( gint ligne )
 	     ||
 	     gsb_data_report_get_show_report_transactions (current_report_number))
 	{
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -321,15 +321,15 @@ gint etat_affiche_affiche_total_sous_categ ( gint ligne )
 		else
 		    text = g_strdup(COLON(_("Sub-categories total")));
 	    }
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
 	    text = gsb_real_get_string_with_currency (montant_sous_categ_etat, devise_categ_etat, TRUE);
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    ligne++;
 	}
 	else
@@ -352,7 +352,7 @@ gint etat_affiche_affiche_total_sous_categ ( gint ligne )
 		text = gsb_real_get_string_with_currency ( montant_sous_categ_etat,
 							   devise_categ_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 	}
@@ -399,7 +399,7 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	     ||
 	     gsb_data_report_get_show_report_transactions (current_report_number))
 	{
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -434,15 +434,15 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 		    text = g_strdup(COLON(_("Budgetary lines total")));
 	    }
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
 	    text = gsb_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 	}
 	else
@@ -463,7 +463,7 @@ gint etat_affiche_affiche_total_ib ( gint ligne )
 	    else
 		text = gsb_real_get_string_with_currency ( montant_ib_etat, devise_ib_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 	}
@@ -510,7 +510,7 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 	     gsb_data_report_get_show_report_transactions (current_report_number))
 	{
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -548,15 +548,15 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 		    text = g_strdup(COLON(_("Sub-budgetary lines total")));
 	    }
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
 	    text = gsb_real_get_string_with_currency (montant_sous_ib_etat, devise_ib_etat, TRUE );
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 	}
 	else
@@ -581,7 +581,7 @@ gint etat_affiche_affiche_total_sous_ib ( gint ligne )
 	    else
 		text = gsb_real_get_string_with_currency ( montant_sous_ib_etat, devise_ib_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 	}
@@ -624,7 +624,7 @@ gint etat_affiche_affiche_total_compte ( gint ligne )
 	     ||
 	     gsb_data_report_get_show_report_transactions (current_report_number))
 	{
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -659,15 +659,15 @@ gint etat_affiche_affiche_total_compte ( gint ligne )
 		    text = g_strdup(COLON(_("Account total")));
 	    }
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
 	    text = gsb_real_get_string_with_currency (montant_compte_etat, devise_compte_en_cours_etat, TRUE );
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 	}
 	else
@@ -690,7 +690,7 @@ gint etat_affiche_affiche_total_compte ( gint ligne )
 	    else
 		text = gsb_real_get_string_with_currency ( montant_compte_etat, devise_compte_en_cours_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );  
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );  
 	    g_free ( text );
 	    ligne++;
 	}
@@ -732,7 +732,7 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 	if ( gsb_data_report_get_show_report_transactions (current_report_number))
 	{
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 
 	    etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
@@ -767,15 +767,15 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 		    text = g_strdup(COLON(_("Payee total")));
 	    }
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( text );
 
 	    text = gsb_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 
-	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	    ligne++;
 	}
 	else
@@ -797,7 +797,7 @@ gint etat_affiche_affiche_total_tiers ( gint ligne )
 	    else
 		text = gsb_real_get_string_with_currency (montant_tiers_etat, devise_tiers_etat, TRUE );
 
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	    g_free ( text );
 	    ligne++;
 	}
@@ -1062,21 +1062,21 @@ gint etat_affiche_affiche_total_periode ( gint transaction_number,
 
 	/*       si on arrive ici, c'est qu'il y a un chgt de période ou que c'est forcé */
 
-	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	ligne++;
 
 	etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
 	ligne++;
 
-	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	g_free ( text );
 
 	text = gsb_real_get_string_with_currency (montant_periode_etat, devise_generale_etat, TRUE );
-	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	g_free ( text );
 	ligne++;
 
-	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	ligne++;
 
 	montant_periode_etat = null_real;
@@ -1216,21 +1216,21 @@ gint etat_affiche_affiche_total_exercice ( gint transaction_number,
 
 	/*       si on arrive ici, c'est qu'il y a un chgt de période ou que c'est forcé */
 
-	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	ligne++;
 
 	etat_affiche_attach_hsep ( 1, nb_colonnes, ligne, ligne + 1 );
 	ligne++;
 
-	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+	etat_affiche_attach_label ( text, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	g_free ( text );
 
 	text = gsb_real_get_string_with_currency (montant_exo_etat, devise_generale_etat, TRUE );
-	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+	etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	g_free ( text );
 	ligne++;
 
-	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	ligne++;
 
 	montant_exo_etat = null_real;
@@ -1285,11 +1285,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 	    if ( gsb_data_report_get_report_can_click (current_report_number))
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 	    }
 	    else
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    }
 
 	    etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
@@ -1303,11 +1303,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 	    if ( gsb_data_report_get_report_can_click (current_report_number))
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 	    }
 	    else
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    }
 
 	    etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
@@ -1322,11 +1322,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 	    if ( gsb_data_report_get_report_can_click (current_report_number))
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 	    }
 	    else
 	    {
-		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    }
 
 	    etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
@@ -1343,11 +1343,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1365,11 +1365,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1410,11 +1410,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 	    {
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		g_free (text);
 	    }
@@ -1434,11 +1434,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1457,18 +1457,18 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
 	    }
 	    else
 	    {
-		etat_affiche_attach_label ( NULL, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		etat_affiche_attach_label ( NULL, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    }
 
 	    etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
@@ -1482,11 +1482,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 	    {
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		g_free (text);
 	    }
@@ -1538,11 +1538,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1561,11 +1561,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1585,11 +1585,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		if (text)
 		    g_free (text);
@@ -1607,11 +1607,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 	    {
 		if ( gsb_data_report_get_report_can_click (current_report_number))
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, transaction_number );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, transaction_number );
 		}
 		else
 		{
-		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, 0 );
+		    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
 		}
 		g_free (text);
 	    }
@@ -1628,11 +1628,11 @@ gint etat_affiche_affichage_ligne_ope ( gint transaction_number,
 
 	if ( gsb_data_report_get_report_can_click (current_report_number))
 	{
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, RIGHT, transaction_number );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_RIGHT, transaction_number );
 	}
 	else
 	{
-	    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, RIGHT, 0 );
+	    etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, ALIGN_RIGHT, 0 );
 	}
 	if (text)
 	    g_free (text);
@@ -1659,7 +1659,7 @@ gint etat_affiche_affiche_total_partiel ( gsb_real total_partie,
     current_report_number = gsb_gui_navigation_get_current_report ();
 
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_hsep ( 0, nb_colonnes, ligne, ligne + 1 );
@@ -1694,18 +1694,18 @@ gint etat_affiche_affiche_total_partiel ( gsb_real total_partie,
 	    text = g_strdup(COLON(_("Total income")));
     }
 
-    etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+    etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
     g_free ( text );
 
     text = gsb_real_get_string_with_currency (total_partie, devise_generale_etat, TRUE );
-    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
     g_free ( text );
     ligne++;
 
     etat_affiche_attach_hsep ( 0, nb_colonnes, ligne, ligne + 1 );
     ligne++;
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, CENTER, 0 );
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes - 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     nom_categ_en_cours = NULL;
@@ -1730,7 +1730,7 @@ gint etat_affiche_affiche_total_general ( gsb_real total_general,
     current_report_number = gsb_gui_navigation_get_current_report ();
 
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes, ligne, ligne + 1, CENTER, 0 );
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes, ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_hsep ( 0, nb_colonnes, ligne, ligne + 1 );
@@ -1748,18 +1748,18 @@ gint etat_affiche_affiche_total_general ( gsb_real total_general,
     else
 	text = g_strdup(COLON(_("General total")));
 
-    etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, LEFT, 0 );
+    etat_affiche_attach_label ( text, TEXT_NORMAL, 0, nb_colonnes - 1, ligne, ligne + 1, ALIGN_LEFT, 0 );
     g_free ( text );
 
     text = gsb_real_get_string_with_currency (total_general, devise_generale_etat, TRUE );
-    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, RIGHT, 0 );
+    etat_affiche_attach_label ( text, TEXT_NORMAL, nb_colonnes - 1, nb_colonnes, ligne, ligne + 1, ALIGN_RIGHT, 0 );
     g_free ( text );
     ligne++;
 
     etat_affiche_attach_hsep ( 0, nb_colonnes, ligne, ligne + 1 );
     ligne++;
 
-    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes, ligne, ligne + 1, CENTER, 0 );
+    etat_affiche_attach_label ( NULL, TEXT_NORMAL, 1, nb_colonnes, ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     return ( ligne );
@@ -1865,7 +1865,7 @@ gint etat_affiche_affiche_categ_etat ( gint transaction_number,
 	    }
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1,
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
 	}
@@ -1950,7 +1950,7 @@ gint etat_affiche_affiche_sous_categ_etat ( gint transaction_number,
 	    }
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free (pointeur_char);
 	    ligne++;
 	}
@@ -2031,7 +2031,7 @@ gint etat_affiche_affiche_ib_etat ( gint transaction_number,
 					      NULL );
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
 	}
@@ -2119,7 +2119,7 @@ gint etat_affiche_affiche_sous_ib_etat ( gint transaction_number,
 	    }
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
 	}
@@ -2189,7 +2189,7 @@ gint etat_affiche_affiche_compte_etat ( gint transaction_number,
 	    nom_compte_en_cours = gsb_data_account_get_name (gsb_data_transaction_get_account_number (transaction_number));
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
 	}
@@ -2267,7 +2267,7 @@ gint etat_affiche_affiche_tiers_etat ( gint transaction_number,
 					      NULL );
 
 	    etat_affiche_attach_label ( pointeur_char, TEXT_NORMAL, 0, nb_colonnes-1, 
-					ligne, ligne + 1, LEFT, 0 );
+					ligne, ligne + 1, ALIGN_LEFT, 0 );
 	    g_free ( pointeur_char );
 	    ligne++;
 	}
@@ -2289,15 +2289,15 @@ gint etat_affiche_affiche_tiers_etat ( gint transaction_number,
 gint etat_affiche_affiche_titre_revenus_etat ( gint ligne )
 {
     etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_label ( _("Incomes"), TEXT_LARGE, 0, nb_colonnes-1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     return ( ligne );
@@ -2309,15 +2309,15 @@ gint etat_affiche_affiche_titre_revenus_etat ( gint ligne )
 gint etat_affiche_affiche_titre_depenses_etat ( gint ligne )
 {
     etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_label ( _("Outgoings"), TEXT_LARGE, 0, nb_colonnes-1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     etat_affiche_attach_label ( NULL, TEXT_NORMAL, 0, 1, 
-				ligne, ligne + 1, CENTER, 0 );
+				ligne, ligne + 1, ALIGN_CENTER, 0 );
     ligne++;
 
     return ( ligne );
@@ -2395,91 +2395,91 @@ gint etat_affiche_affiche_titres_colonnes ( gint ligne )
 
     if ( gsb_data_report_get_show_report_transaction_number (current_report_number))
     {
-	etat_affiche_attach_label ( _("Number"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Number"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_date (current_report_number))
     {
-	etat_affiche_attach_label ( _("Date"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Date"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_value_date (current_report_number))
     {
-	etat_affiche_attach_label ( _("Value date"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Value date"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_financial_year (current_report_number))
     {
-	etat_affiche_attach_label ( _("Financial year"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Financial year"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_payee (current_report_number))
     {
-	etat_affiche_attach_label ( _("Payee"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Payee"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_category (current_report_number))
     {
-	etat_affiche_attach_label ( _("Category"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Category"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_budget (current_report_number))
     {
-	etat_affiche_attach_label ( _("Budgetary line"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Budgetary line"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_note (current_report_number))
     {
-	etat_affiche_attach_label ( _("Notes"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Notes"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_method_of_payment (current_report_number))
     {
-	etat_affiche_attach_label ( _("Payment methods"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Payment methods"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_method_of_payment_content (current_report_number))
     {
-	etat_affiche_attach_label ( _("Cheque"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Cheque"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_voucher (current_report_number))
     {
-	etat_affiche_attach_label ( _("Voucher"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Voucher"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_bank_references (current_report_number))
     {
-	etat_affiche_attach_label ( _("Bank references"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Bank references"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
 
     if ( gsb_data_report_get_show_report_marked (current_report_number))
     {
-	etat_affiche_attach_label ( _("Statement"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, 0 );
+	etat_affiche_attach_label ( _("Statement"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, ALIGN_CENTER, 0 );
 	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
 	colonne = colonne + 2;
     }
diff --git a/src/etats_gtktable.c b/src/etats_gtktable.c
index cfc3fb7..56d0b42 100644
--- a/src/etats_gtktable.c
+++ b/src/etats_gtktable.c
@@ -107,13 +107,13 @@ void gtktable_attach_label ( gchar * text, gdouble properties, int x, int x2, in
 
     switch (align) 
     {
-	case LEFT:
+	case ALIGN_LEFT:
 	    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
 	    break;
-	case CENTER:
+	case ALIGN_CENTER:
 	    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.5, 0.0 );
 	    break;
-	case RIGHT:
+	case ALIGN_RIGHT:
 	    gtk_misc_set_alignment ( GTK_MISC ( label ), 1.0, 0.0 );
 	    break;
     }
diff --git a/src/etats_html.c b/src/etats_html.c
index 5138eb3..0207424 100644
--- a/src/etats_html.c
+++ b/src/etats_html.c
@@ -139,15 +139,15 @@ void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y,
 
     switch ( align )
     {
-	case LEFT:
+	case ALIGN_LEFT:
 	    fprintf ( html_out, " align=\"left\"" );
 	    break;
 
-	case RIGHT:
+	case ALIGN_RIGHT:
 	    fprintf ( html_out, " align=\"right\"" );
 	    break;
 
-	case CENTER:
+	case ALIGN_CENTER:
 	    fprintf ( html_out, " align=\"center\"" );
 	    break;
     }
diff --git a/src/etats_latex.c b/src/etats_latex.c
index 286b14a..1135ddb 100644
--- a/src/etats_latex.c
+++ b/src/etats_latex.c
@@ -142,15 +142,15 @@ void latex_attach_label ( gchar * text, gdouble properties, int x, int x2, int y
 
     switch ( align )
     {
-	case LEFT:
+	case ALIGN_LEFT:
 	    fprintf ( file_out, "\\raggedright\n" );
 	    break;
 
-	case RIGHT:
+	case ALIGN_RIGHT:
 	    fprintf ( file_out, "\\raggedleft\n" );
 	    break;
 
-	case CENTER:
+	case ALIGN_CENTER:
 	    break;
     }
 
diff --git a/src/gsb_file_load.c b/src/gsb_file_load.c
index 1631fc5..ae9ceb8 100644
--- a/src/gsb_file_load.c
+++ b/src/gsb_file_load.c
@@ -195,6 +195,7 @@ extern GdkColor split_background;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
 extern GdkColor text_color[2];
 extern gchar *titre_fichier;
+extern gint transaction_col_align[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint valeur_echelle_recherche_date_import;
 /*END_EXTERN*/
@@ -967,6 +968,23 @@ void gsb_file_load_general_part ( const gchar **attribute_names,
     }
 
     else if ( !strcmp ( attribute_names[i],
+                        "Transaction_column_align" ))
+    {
+        gchar **pointeur_char;
+        gint j;
+
+        /* the transactions columns are xx-xx-xx-xx and we want to set in transaction_col_width[1-2-3...] */
+        pointeur_char = g_strsplit ( attribute_values[i],
+                        "-",
+                        0 );
+
+        for ( j=0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
+        transaction_col_align[j] = utils_str_atoi ( pointeur_char[j]);
+
+        g_strfreev ( pointeur_char );
+    }
+
+    else if ( !strcmp ( attribute_names[i],
                         "Scheduler_column_width" ))
     {
         gchar **pointeur_char;
diff --git a/src/gsb_file_save.c b/src/gsb_file_save.c
index 8bab3e7..17f755d 100644
--- a/src/gsb_file_save.c
+++ b/src/gsb_file_save.c
@@ -168,6 +168,7 @@ extern GdkColor split_background;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
 extern GdkColor text_color[2];
 extern gchar *titre_fichier;
+extern gint transaction_col_align[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint valeur_echelle_recherche_date_import;
 /*END_EXTERN*/
@@ -571,6 +572,7 @@ gulong gsb_file_save_general_part ( gulong iterator,
     gchar *transactions_view;
     gchar *scheduler_column_width_write;
     gchar *transaction_column_width_write;
+    gchar *transaction_column_align_write;
     gchar *new_string;
     gchar *skipped_lines_string;
     gchar *bet_array_column_width_write;
@@ -629,6 +631,23 @@ gulong gsb_file_save_general_part ( gulong iterator,
 	else
 	    scheduler_column_width_write  = utils_str_itoa ( scheduler_col_width[i] );
 
+    /* prepare transaction_column_align_write */
+    transaction_column_align_write = NULL;
+
+    for ( i=0 ; i<CUSTOM_MODEL_VISIBLE_COLUMNS ; i++ )
+	if ( transaction_column_align_write )
+	{
+	    transaction_column_align_write = g_strconcat (
+                        first_string_to_free = transaction_column_align_write,
+                        "-",
+                        second_string_to_free = utils_str_itoa ( transaction_col_align[i] ),
+                        NULL );
+	    g_free ( first_string_to_free );
+	    g_free ( second_string_to_free );
+	}
+	else
+	    transaction_column_align_write  = utils_str_itoa ( transaction_col_align[i] );
+
     /* CSV skipped lines */
     skipped_lines_string = utils_str_itoa ( etat.csv_skipped_lines[0] );
     for ( i = 1; i < CSV_MAX_TOP_LINES ; i ++ )
@@ -705,6 +724,7 @@ gulong gsb_file_save_general_part ( gulong iterator,
 					   "\t\tThree_lines_showed=\"%d\"\n"
 					   "\t\tRemind_form_per_account=\"%d\"\n"
 					   "\t\tTransaction_column_width=\"%s\"\n"
+					   "\t\tTransaction_column_align=\"%s\"\n"
 					   "\t\tScheduler_column_width=\"%s\"\n"
 					   "\t\tCombofix_mixed_sort=\"%d\"\n"
 					   "\t\tCombofix_max_item=\"%d\"\n"
@@ -754,6 +774,7 @@ gulong gsb_file_save_general_part ( gulong iterator,
 	display_three_lines,
     0,
 	my_safe_null_str(transaction_column_width_write),
+	my_safe_null_str ( transaction_column_align_write ),
 	my_safe_null_str(scheduler_column_width_write),
 	etat.combofix_mixed_sort,
 	etat.combofix_max_item,
diff --git a/src/gsb_transactions_list.c b/src/gsb_transactions_list.c
index 59c9ec3..a13d43a 100644
--- a/src/gsb_transactions_list.c
+++ b/src/gsb_transactions_list.c
@@ -76,6 +76,8 @@ static GtkWidget *gsb_gui_create_cell_contents_menu ( int x, int y );
 static gboolean gsb_transactions_list_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev,
                         gpointer null );
+static gboolean gsb_transactions_list_change_alignement ( GtkWidget *menu_item,
+                        gint *no_column );
 static gboolean gsb_transactions_list_change_sort_column ( GtkTreeViewColumn *tree_view_column,
                         gint *column_ptr );
 static gboolean gsb_transactions_list_change_sort_type ( GtkWidget *menu_item,
@@ -121,6 +123,9 @@ GtkTreeViewColumn *transactions_tree_view_columns[CUSTOM_MODEL_N_VISIBLES_COLUMN
 /* the initial width of each column */
 gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 
+/* the initial alignment of each column */
+gint transaction_col_align[CUSTOM_MODEL_N_VISIBLES_COLUMN];
+
 /* adr de la barre d'outils */
 GtkWidget *barre_outils;
 
@@ -178,7 +183,6 @@ extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COL
 extern GtkWidget *window;
 /*END_EXTERN*/
 
-
 /** All delete messages */
 struct conditional_message delete_msg[] =
 {
@@ -352,10 +356,6 @@ GtkWidget *gsb_transactions_list_make_gui_list ( void )
 void gsb_transactions_list_create_tree_view_columns ( void )
 {
     gint i;
-    gfloat alignment[] = {
-	COLUMN_CENTER, COLUMN_CENTER, COLUMN_LEFT,
-	COLUMN_CENTER, COLUMN_RIGHT, COLUMN_RIGHT, COLUMN_RIGHT
-    };
     gint column_balance;
 
     /* get the position of the amount column to set it in red */
@@ -368,7 +368,7 @@ void gsb_transactions_list_create_tree_view_columns ( void )
 
 	cell_renderer = gtk_cell_renderer_text_new ();
 	g_object_set ( G_OBJECT ( cell_renderer ),
-		                "xalign", alignment[i],
+		                "xalign", ( gfloat )transaction_col_align[i]/2,
 		                NULL );
 	transactions_tree_view_columns[i] = gtk_tree_view_column_new_with_attributes (
                         _(titres_colonnes_liste_operations[i]),
@@ -378,6 +378,9 @@ void gsb_transactions_list_create_tree_view_columns ( void )
 					    "font", CUSTOM_MODEL_FONT,
 					    NULL );
 
+    g_object_set_data ( G_OBJECT ( transactions_tree_view_columns[i] ),
+                        "cell_renderer", cell_renderer );
+
 	if ( i == column_balance )
 	    gtk_tree_view_column_add_attribute ( transactions_tree_view_columns[i],
 						cell_renderer,
@@ -405,7 +408,7 @@ void gsb_transactions_list_create_tree_view_columns ( void )
 	}
 
 	gtk_tree_view_column_set_alignment ( transactions_tree_view_columns[i],
-					     alignment[i] );
+					     ( gfloat )transaction_col_align[i]/2 );
 
     gtk_tree_view_column_set_sizing ( transactions_tree_view_columns[i],
 					    GTK_TREE_VIEW_COLUMN_FIXED );
@@ -2959,7 +2962,6 @@ gboolean gsb_transactions_list_title_column_button_press ( GtkWidget *button,
     gint column_number;
 
     column_number = GPOINTER_TO_INT (no_column);
-    devel_debug_int (column_number);
 
     switch ( ev -> button )
     {
@@ -2989,10 +2991,10 @@ gboolean gsb_transactions_list_title_column_button_press ( GtkWidget *button,
                 if ( menu == NULL )
                 {
                     menu = gtk_menu_new ();
-                    /*  sort by line */
+                    /* sort by line */
                     menu_item = gtk_menu_item_new_with_label ( _("Sort list by :") );
                     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
-                    gtk_widget_show_all ( menu_item );
+                    gtk_widget_show ( menu_item );
 
                     menu_item = gtk_separator_menu_item_new ();
                     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
@@ -3019,11 +3021,69 @@ gboolean gsb_transactions_list_title_column_button_press ( GtkWidget *button,
                 gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
                 gtk_widget_show ( menu_item );
             }
-
 	    }
 
         if ( menu )
         {
+            gfloat alignement;
+
+            menu_item = gtk_separator_menu_item_new ();
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            gtk_widget_show ( menu_item );
+
+            /* alignement */
+            alignement = gtk_tree_view_column_get_alignment (
+                        gtk_tree_view_get_column ( GTK_TREE_VIEW ( transactions_tree_view ),
+                        column_number ) );
+            menu_item = gtk_menu_item_new_with_label ( _("alignment :") );
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            gtk_widget_show ( menu_item );
+
+            menu_item = gtk_separator_menu_item_new ();
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            gtk_widget_show ( menu_item );
+
+            menu_item = gtk_radio_menu_item_new_with_label ( NULL, _("LEFT") );
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            if ( alignement == COLUMN_LEFT )
+                gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM ( menu_item ), TRUE );
+            g_object_set_data ( G_OBJECT ( menu_item ),
+                        "alignement",
+                        GINT_TO_POINTER ( ALIGN_LEFT ) );
+            g_signal_connect ( G_OBJECT(menu_item),
+                        "activate",
+                        G_CALLBACK ( gsb_transactions_list_change_alignement ),
+                        no_column );
+            gtk_widget_show ( menu_item );
+
+            menu_item = gtk_radio_menu_item_new_with_label_from_widget ( GTK_RADIO_MENU_ITEM (
+                        menu_item ),_("CENTER") );
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            if ( alignement == COLUMN_CENTER )
+                gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM ( menu_item ), TRUE );
+            g_object_set_data ( G_OBJECT ( menu_item ),
+                        "alignement",
+                        GINT_TO_POINTER ( ALIGN_CENTER ) );
+            g_signal_connect ( G_OBJECT(menu_item),
+                        "activate",
+                        G_CALLBACK ( gsb_transactions_list_change_alignement ),
+                        no_column );
+            gtk_widget_show ( menu_item );
+
+            menu_item = gtk_radio_menu_item_new_with_label_from_widget ( GTK_RADIO_MENU_ITEM (
+                        menu_item ),_("RIGHT") );
+            gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
+            if ( alignement == COLUMN_RIGHT )
+                gtk_check_menu_item_set_active ( GTK_CHECK_MENU_ITEM ( menu_item ), TRUE );
+            g_object_set_data ( G_OBJECT ( menu_item ),
+                        "alignement",
+                        GINT_TO_POINTER ( ALIGN_RIGHT ) );
+            g_signal_connect ( G_OBJECT(menu_item),
+                        "activate",
+                        G_CALLBACK ( gsb_transactions_list_change_alignement ),
+                        no_column );
+            gtk_widget_show ( menu_item );
+
             gtk_menu_popup ( GTK_MENU ( menu ), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time () );
             gtk_widget_show ( menu );
         }
@@ -3075,7 +3135,6 @@ gboolean gsb_transactions_list_change_sort_type ( GtkWidget *menu_item,
 }
 
 
-
 /**
  * called by a click on a column title ; the sort of the list is automatic,
  * that function make the background color and the rest to be updated
@@ -3681,6 +3740,57 @@ void gsb_transactions_list_display_contra_transaction ( gint *element_ptr )
 }
 
 
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_transactions_list_change_alignement ( GtkWidget *menu_item,
+                        gint *no_column )
+{
+    GtkTreeViewColumn *column;
+    GtkCellRenderer *cell_renderer;
+    gint column_number;
+    gint alignement;
+    gfloat xalign = 0.0;
+
+    if ( !gtk_check_menu_item_get_active ( GTK_CHECK_MENU_ITEM ( menu_item ) ) )
+        return FALSE;
+
+    column_number = GPOINTER_TO_INT ( no_column );
+    column = gtk_tree_view_get_column ( GTK_TREE_VIEW (
+                        transactions_tree_view ),
+                        column_number );
+    alignement = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( menu_item ), "alignement" ) );
+    cell_renderer = g_object_get_data ( G_OBJECT ( column ), "cell_renderer" );
+
+    switch ( alignement )
+    {
+        case ALIGN_LEFT:
+            xalign = 0.0;
+            break;
+        case ALIGN_CENTER:
+            xalign = 0.5;
+            break;
+        case ALIGN_RIGHT:
+            xalign = 1.0;
+            break;
+    }
+
+    transaction_col_align[column_number] = alignement;
+    gtk_tree_view_column_set_alignment  ( column, xalign );
+    g_object_set ( G_OBJECT ( cell_renderer ),
+		                "xalign", xalign,
+		                NULL );
+    
+    if ( etat.modification_fichier == 0 )
+        modification_fichier ( TRUE );
+
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
diff --git a/src/structures.h b/src/structures.h
index 8c544f4..f478234 100644
--- a/src/structures.h
+++ b/src/structures.h
@@ -210,7 +210,7 @@ struct struct_payee_asso
 
 enum alignement
 {
-    LEFT, CENTER, RIGHT,
+    ALIGN_LEFT, ALIGN_CENTER, ALIGN_RIGHT,
 };
 
 
diff --git a/src/traitement_variables.c b/src/traitement_variables.c
index 08538ba..50fc1d5 100644
--- a/src/traitement_variables.c
+++ b/src/traitement_variables.c
@@ -183,6 +183,7 @@ extern gint scheduler_current_tree_view_width;
 extern GtkWidget *solde_label;
 extern GtkWidget *solde_label_pointe;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
+extern gint transaction_col_align[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint valeur_echelle_recherche_date_import;
 /*END_EXTERN*/
@@ -238,6 +239,7 @@ void init_variables ( void )
     gint scheduler_col_width_init[SCHEDULER_COL_VISIBLE_COLUMNS] = {10, 12, 36, 12, 12, 12, 12 };
     gint transaction_col_width_init[CUSTOM_MODEL_VISIBLE_COLUMNS] = {10, 12, 36, 6, 12, 12, 12 };
     gint bet_array_col_width_init[BET_ARRAY_COLUMNS] = {15, 40, 15, 15, 15 };
+    gint transaction_col_align_init[CUSTOM_MODEL_VISIBLE_COLUMNS] = { 1, 1, 0, 1, 2, 2, 2 };
     gint i;
     
 /* xxx on devrait séparer ça en 2 : les variables liées au fichier de compte, qui doivent être remises  à 0,
@@ -362,11 +364,13 @@ void init_variables ( void )
      * gsb_currency_update_combobox_currency_list */
     detail_devise_compte = NULL;
 
-    /* defaut value for width of columns */
+    /* defaut value for width and align of columns */
+    for ( i = 0 ; i < CUSTOM_MODEL_VISIBLE_COLUMNS ; i++ )
+        transaction_col_width[i] = transaction_col_width_init[i];
     for ( i = 0 ; i < CUSTOM_MODEL_VISIBLE_COLUMNS ; i++ )
-    transaction_col_width[i] = transaction_col_width_init[i];
-     for ( i = 0 ; i < SCHEDULER_COL_VISIBLE_COLUMNS ; i++ )
-    scheduler_col_width[i] = scheduler_col_width_init[i];
+        transaction_col_align[i] = transaction_col_align_init[i];
+    for ( i = 0 ; i < SCHEDULER_COL_VISIBLE_COLUMNS ; i++ )
+        scheduler_col_width[i] = scheduler_col_width_init[i];
     
     navigation_tree_view = NULL;
 


hooks/post-receive
-- 
grisbi


More information about the cvs mailing list